declare module 'react-smart-hooks';
import { RefObject } from 'react';

// Type for useWindowSize hook
export interface WindowSize {
    width: number;
    height: number;
}
export interface UseWindowSize {
    (): WindowSize;
}
export declare const getWindowSize: () => WindowSize;

// Type for the useLocalStorage hook
export interface UseLocalStorageProps {
    key: string;
    initialValue: any;
}
export type UseLocalStorageResult = [any, (value: any) => void];
export interface UseLocalStorage {
    (props: UseLocalStorageProps): UseLocalStorageResult;
}

// Type for the useOutsideClick hook
export interface UseOutsideClickProps {
    refs: RefObject<HTMLElement>[];
    onClick: () => void;
}
export type UseOutsideClickResult = [any, (value: any) => void];
export interface UseOutsideClick {
    (props: UseOutsideClickProps): UseOutsideClickResult;
}

// Type for useDeviceDetection hook
export interface Breakpoints {
    smallMobile: number;
    mobile: number;
    phablet: number;
    smallTablet: number;
    tablet: number;
    smallDesktop: number;
    desktop: number;
}
export interface UseDeviceDetectionResult {
    deviceType: string | null;
}

// Type for useAbsoluteURL hook
export type useAbsoluteURLProps = string;

// Type for useZIndexModal hook
export interface useZIndexModalProps {
    indexNumberLimit?: number;
    prefix?: string;
}
export interface IndexModalProps {
    selector?: string;
    indexCssVar?: string;
    indexNum?: number;
    indexLimit?: number;
}

// Export the hook function
declare const useWindowSize: UseWindowSize;
declare const useLocalStorage: UseLocalStorage;
declare const useOutsideClick: UseOutsideClick;
declare const useDeviceDetection: () => UseDeviceDetectionResult;
declare const useAbsoluteURL: (pathname?: useAbsoluteURLProps) => string;
declare const useZIndexModal: (props: useZIndexModalProps) => void;

export { useWindowSize, useLocalStorage, useOutsideClick, useDeviceDetection, useAbsoluteURL, useZIndexModal };